pub fn decoded_values_equal(a: &DecodedValue, b: &DecodedValue) -> boolExpand description
Structural equality for DecodedValue with NaN treated as equal to NaN
(avoids spurious monitor flaps when a float field is NaN on both sides).
pub fn decoded_values_equal(a: &DecodedValue, b: &DecodedValue) -> boolStructural equality for DecodedValue with NaN treated as equal to NaN
(avoids spurious monitor flaps when a float field is NaN on both sides).