Module spvirit_encode

Module spvirit_encode 

PVA message encoding helpers.

Functions

encode_authnz_user_host
encode_beacon
encode_client_connection_validation
encode_connection_validated
encode_connection_validation
encode_control_message
encode_create_channel_error
encode_create_channel_request
encode_create_channel_response
encode_destroy_channel_response
encode_get_field_error
encode_get_field_request
encode_get_field_response
encode_get_request
encode_header
encode_message_error
encode_monitor_data_response
encode_monitor_data_response_filtered
Like encode_monitor_data_response_payload but encodes only the fields present in filtered_desc.
encode_monitor_data_response_payload
encode_monitor_request
encode_op_data_response
encode_op_data_response_filtered
Like encode_op_data_response_payload but encodes only the fields present in filtered_desc (as negotiated in the INIT response).
encode_op_data_response_payload
encode_op_error
encode_op_get_data_response_payload
encode_op_init_response
encode_op_init_response_desc
encode_op_put_get_data_error_response
encode_op_put_get_data_response
encode_op_put_get_data_response_payload
encode_op_put_get_init_error_response
encode_op_put_get_init_response
encode_op_put_getput_response
encode_op_put_getput_response_payload
encode_op_put_response
encode_op_put_status_response
encode_op_request
encode_op_rpc_data_response_payload
encode_op_status_error_response
encode_op_status_response
encode_put_request
encode_rpc_request
encode_search_request
encode_search_response
encode_size_pva
encode_status_fatal
Encode a FATAL status (type byte 0x03) with a message.
encode_status_warning
Encode a WARNING status (type byte 0x01) with a message.
encode_string_pva
format_pva_address
Format a 16-byte PVA address field as a human-readable IP string.
ip_from_bytes
Decode a 16-byte PVA address field to an IpAddr.
ip_to_bytes
Convert an IpAddr to the 16-byte PVA wire representation.
socket_addr_from_pva_bytes