PvdDecoder

Struct PvdDecoder 

pub struct PvdDecoder { /* private fields */ }
PVD Decoder state

Implementations

Source

impl PvdDecoder

pub fn new(is_be: bool) -> Self

pub fn decode_size(&self, data: &[u8]) -> Option<(usize, usize)>

Decode a size value (PVA variable-length encoding)

pub fn decode_string(&self, data: &[u8]) -> Option<(String, usize)>

Decode a string

pub fn parse_field_desc(&self, data: &[u8]) -> Option<(FieldDesc, usize)>

Parse field description from introspection data

pub fn parse_introspection(&self, data: &[u8]) -> Option<StructureDesc>

Parse the full type introspection from INIT response

pub fn parse_introspection_with_len( &self, data: &[u8], ) -> Option<(StructureDesc, usize)>

Parse full type introspection and return consumed bytes.

pub fn decode_value( &self, data: &[u8], field_type: &FieldType, ) -> Option<(DecodedValue, usize)>

Decode value according to field type

pub fn decode_structure( &self, data: &[u8], desc: &StructureDesc, ) -> Option<(DecodedValue, usize)>

Decode a structure value using the field descriptions

pub fn decode_structure_with_bitset( &self, data: &[u8], desc: &StructureDesc, ) -> Option<(DecodedValue, usize)>

Decode a structure with a bitset indicating which fields are present This is used for delta updates in MONITOR

pub fn decode_structure_with_bitset_and_overrun( &self, data: &[u8], desc: &StructureDesc, ) -> Option<(DecodedValue, usize)>

Decode a structure with changed and overrun bitsets (MONITOR updates)

pub fn decode_structure_with_bitset_then_overrun( &self, data: &[u8], desc: &StructureDesc, ) -> Option<(DecodedValue, usize)>

Decode a structure with changed bitset, data, then overrun bitset (spec order)