pub struct PvdDecoder { /* private fields */ }Expand description
PVD Decoder state
Implementations
Sourceimpl PvdDecoder
impl PvdDecoder
pub fn new(is_be: bool) -> Self
Sourcepub fn decode_size(&self, data: &[u8]) -> Option<(usize, usize)>
pub fn decode_size(&self, data: &[u8]) -> Option<(usize, usize)>
Decode a size value (PVA variable-length encoding)
Sourcepub fn parse_field_desc(&self, data: &[u8]) -> Option<(FieldDesc, usize)>
pub fn parse_field_desc(&self, data: &[u8]) -> Option<(FieldDesc, usize)>
Parse field description from introspection data
Sourcepub fn parse_introspection(&self, data: &[u8]) -> Option<StructureDesc>
pub fn parse_introspection(&self, data: &[u8]) -> Option<StructureDesc>
Parse the full type introspection from INIT response
Sourcepub fn parse_introspection_with_len(
&self,
data: &[u8],
) -> Option<(StructureDesc, usize)>
pub fn parse_introspection_with_len( &self, data: &[u8], ) -> Option<(StructureDesc, usize)>
Parse full type introspection and return consumed bytes.
Sourcepub fn decode_value(
&self,
data: &[u8],
field_type: &FieldType,
) -> Option<(DecodedValue, usize)>
pub fn decode_value( &self, data: &[u8], field_type: &FieldType, ) -> Option<(DecodedValue, usize)>
Decode value according to field type
Sourcepub fn decode_structure(
&self,
data: &[u8],
desc: &StructureDesc,
) -> Option<(DecodedValue, usize)>
pub fn decode_structure( &self, data: &[u8], desc: &StructureDesc, ) -> Option<(DecodedValue, usize)>
Decode a structure value using the field descriptions
Sourcepub fn decode_structure_with_bitset(
&self,
data: &[u8],
desc: &StructureDesc,
) -> Option<(DecodedValue, usize)>
pub fn decode_structure_with_bitset( &self, data: &[u8], desc: &StructureDesc, ) -> Option<(DecodedValue, usize)>
Decode a structure with a bitset indicating which fields are present This is used for delta updates in MONITOR
Sourcepub fn decode_structure_with_bitset_and_overrun(
&self,
data: &[u8],
desc: &StructureDesc,
) -> Option<(DecodedValue, usize)>
pub fn decode_structure_with_bitset_and_overrun( &self, data: &[u8], desc: &StructureDesc, ) -> Option<(DecodedValue, usize)>
Decode a structure with changed and overrun bitsets (MONITOR updates)
Sourcepub fn decode_structure_with_bitset_then_overrun(
&self,
data: &[u8],
desc: &StructureDesc,
) -> Option<(DecodedValue, usize)>
pub fn decode_structure_with_bitset_then_overrun( &self, data: &[u8], desc: &StructureDesc, ) -> Option<(DecodedValue, usize)>
Decode a structure with changed bitset, data, then overrun bitset (spec order)